@@ -1,4 +1,5 @@
 import itertools
+import array
 import six
 
 if six.PY2:
@@ -23,7 +24,6 @@ def describe_column(name, typ):
 
 
 class Column(list):
-
     def __init__(self, name, values=[], type=object):
         list.__init__(self)
         self.name = name
@@ -34,6 +34,51 @@ class Column(list):
     def description(self):
         return describe_column(self.name, self.type)
 
+    def validate(self, v):
+        return v is None or isinstance(v, self.type)
+
+    def fn_from_string(self):
+        return self.type
+
+
+class ArrayColumn(array.array):
+
+    PY_TYPE_MAPPING = {
+        'c':str,
+        'b':int,
+        'B':int,
+        'u':unicode,
+        'h':int,
+        'H':int,
+        'i':int,
+        'I':long,
+        'l':int,
+        'L':long,
+        'f':float,
+        'd':float
+    }
+
+    def __new__(cls, name, values=None, type='i'):
+        return array.array.__new__(cls, type)
+
+    def __init__(self, name, values=None, type='i'):
+        self.name = name
+        self.extend(values or [])
+
+
+    def fn_from_string(self):
+        return self.PY_TYPE_MAPPING[self.typecode]
+
+    @property
+    def type(self):
+        return self.typecode
+
+    def validate(self, v):
+        return True # Delegate to underlying class
+
+    @property
+    def description(self):
+        return '%s (%s)' % (self.name, self.type)
 
 class StaticColumn(object):
 
